package org.hornetq.javaee.example.server;

//java imports
import javax.ejb.MessageDrivenBean;
import javax.ejb.MessageDrivenContext;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.ObjectMessage;
import javax.jms.TextMessage;

/**
 * @ejb.bean name="TestMdbMessageBean"
 *           message-selector="TARGET='IMPORT_RUNNER'"
 *           jndi-name="/TestMdb"
 *           acknowledge-mode="Auto-acknowledge"
 *           destination-type="javax.jms.Topic"
 *           subscription-durability="NonDurable"
 *           transaction-type="Bean"
 *
 * @stereotype bean class
 *
 * @ejb.security-identity run-as="execApplRgt"
 *
 * @ejb.env-entry name="topic"
 *                type="java.lang.String"
 *                value="topic/testTopic"
 *
 * @ejb.env-entry name="jms-user"
 *                type="java.lang.String"
 *                value="myuser"
 *
 * @ejb.env-entry name="jms-password"
 *                type="java.lang.String"
 *                value="mypassword"
 *
 * @jboss.destination-jndi-name name="topic/testTopic"
 *
 * @ejb.ejb-ref ejb-name="Ejb2Test"
 *          view-type="local"
 *          ref-name="ejb/Ejb2TestLocal"
 */
public class TestMdbMessageBean
             implements MessageDrivenBean, MessageListener {

    /** The message driven context. */
    private MessageDrivenContext mMDBContext = null;

    /**
     * Ejb create method.
     */
    public void ejbCreate() {
    }

    /**
     * Ejb remove method.
     */
    public void ejbRemove() {
    }

    /**
     * Set the message driven context.
     * @param theMDBContext The context.
     */
    public void setMessageDrivenContext(
        MessageDrivenContext theMDBContext) {
        mMDBContext = theMDBContext;
    }

    /**
     * On message method - run.
     * @param theMessage The incomming message.
     */
    public void onMessage(Message theMessage) {

        System.out.println("Message received: " + theMessage);

        if(theMessage instanceof TextMessage) {
            TextMessage msg = (TextMessage) theMessage;
            try {
                String text = msg.getText();
                System.out.println("Text in message: " + text);

                Ejb2Test1Local ejb1 = Ejb2Test1Util.getLocalHome().create();
                ejb1.test();
            }
            catch(Exception ex) {
                ex.printStackTrace();
            }
        }

    }

}
